<?php

return [
    'Names' => [
        'af' => 'afrîkansî',
        'af_NA' => 'afrîkansî (Namîbya)',
        'af_ZA' => 'afrîkansî (Afrîkaya Başûr)',
        'am' => 'amharî',
        'am_ET' => 'amharî (Etiyopya)',
        'ar' => 'erebî',
        'ar_001' => 'erebî (Cîhan)',
        'ar_AE' => 'erebî (Emîrtiyên Erebî yên Yekbûyî)',
        'ar_BH' => 'erebî (Behreyn)',
        'ar_DJ' => 'erebî (Cîbûtî)',
        'ar_DZ' => 'erebî (Cezayir)',
        'ar_EG' => 'erebî (Misir)',
        'ar_EH' => 'erebî (Sahraya Rojava)',
        'ar_ER' => 'erebî (Erîtrea)',
        'ar_IL' => 'erebî (Îsraêl)',
        'ar_IQ' => 'erebî (Iraq)',
        'ar_JO' => 'erebî (Urdun)',
        'ar_KM' => 'erebî (Komor)',
        'ar_KW' => 'erebî (Kuweyt)',
        'ar_LB' => 'erebî (Libnan)',
        'ar_LY' => 'erebî (Lîbya)',
        'ar_MA' => 'erebî (Maroko)',
        'ar_MR' => 'erebî (Morîtanya)',
        'ar_OM' => 'erebî (Oman)',
        'ar_PS' => 'erebî (Xakên filistînî)',
        'ar_QA' => 'erebî (Qeter)',
        'ar_SA' => 'erebî (Erebistana Siyûdî)',
        'ar_SD' => 'erebî (Sûdan)',
        'ar_SO' => 'erebî (Somalya)',
        'ar_SS' => 'erebî (Sûdana Başûr)',
        'ar_SY' => 'erebî (Sûrî)',
        'ar_TD' => 'erebî (Çad)',
        'ar_TN' => 'erebî (Tûnis)',
        'ar_YE' => 'erebî (Yemen)',
        'as' => 'asamî',
        'as_IN' => 'asamî (Hindistan)',
        'az' => 'azerî',
        'az_AZ' => 'azerî (Azerbaycan)',
        'az_Cyrl' => 'azerî (kirîlî)',
        'az_Cyrl_AZ' => 'azerî (kirîlî, Azerbaycan)',
        'az_Latn' => 'azerî (latînî)',
        'az_Latn_AZ' => 'azerî (latînî, Azerbaycan)',
        'be' => 'belarusî',
        'be_BY' => 'belarusî (Belarûs)',
        'bg' => 'bulgarî',
        'bg_BG' => 'bulgarî (Bulgaristan)',
        'bm' => 'bambarayî',
        'bm_ML' => 'bambarayî (Malî)',
        'bn' => 'bengalî',
        'bn_BD' => 'bengalî (Bangladeş)',
        'bn_IN' => 'bengalî (Hindistan)',
        'bo' => 'tîbetî',
        'bo_CN' => 'tîbetî (Çîn)',
        'bo_IN' => 'tîbetî (Hindistan)',
        'br' => 'bretonî',
        'br_FR' => 'bretonî (Fransa)',
        'bs' => 'bosnî',
        'bs_BA' => 'bosnî (Bosniya û Herzegovîna)',
        'bs_Cyrl' => 'bosnî (kirîlî)',
        'bs_Cyrl_BA' => 'bosnî (kirîlî, Bosniya û Herzegovîna)',
        'bs_Latn' => 'bosnî (latînî)',
        'bs_Latn_BA' => 'bosnî (latînî, Bosniya û Herzegovîna)',
        'ca' => 'katalanî',
        'ca_AD' => 'katalanî (Andorra)',
        'ca_ES' => 'katalanî (Spanya)',
        'ca_FR' => 'katalanî (Fransa)',
        'ca_IT' => 'katalanî (Îtalya)',
        'ce' => 'çeçenî',
        'ce_RU' => 'çeçenî (Rûsya)',
        'cs' => 'çekî',
        'cs_CZ' => 'çekî (Çekya)',
        'cv' => 'çuvaşî',
        'cv_RU' => 'çuvaşî (Rûsya)',
        'cy' => 'weylsî',
        'cy_GB' => 'weylsî (Keyaniya Yekbûyî)',
        'da' => 'danmarkî',
        'da_DK' => 'danmarkî (Danîmarka)',
        'da_GL' => 'danmarkî (Grînlenda)',
        'de' => 'elmanî',
        'de_AT' => 'elmanî (Awistirya)',
        'de_BE' => 'elmanî (Belçîka)',
        'de_CH' => 'elmanî (Swîsre)',
        'de_DE' => 'elmanî (Almanya)',
        'de_IT' => 'elmanî (Îtalya)',
        'de_LI' => 'elmanî (Liechtenstein)',
        'de_LU' => 'elmanî (Lûksembûrg)',
        'dz' => 'conxayî',
        'dz_BT' => 'conxayî (Bûtan)',
        'ee' => 'eweyî',
        'ee_GH' => 'eweyî (Gana)',
        'ee_TG' => 'eweyî (Togo)',
        'el' => 'yewnanî',
        'el_CY' => 'yewnanî (Kîpros)',
        'el_GR' => 'yewnanî (Yewnanistan)',
        'en' => 'îngilîzî',
        'en_001' => 'îngilîzî (Cîhan)',
        'en_150' => 'îngilîzî (Ewropa)',
        'en_AE' => 'îngilîzî (Emîrtiyên Erebî yên Yekbûyî)',
        'en_AG' => 'îngilîzî (Antîgua û Berbûda)',
        'en_AS' => 'îngilîzî (Samoaya Amerîkanî)',
        'en_AT' => 'îngilîzî (Awistirya)',
        'en_AU' => 'îngilîzî (Awistralya)',
        'en_BB' => 'îngilîzî (Barbados)',
        'en_BE' => 'îngilîzî (Belçîka)',
        'en_BI' => 'îngilîzî (Burundî)',
        'en_BM' => 'îngilîzî (Bermûda)',
        'en_BS' => 'îngilîzî (Bahama)',
        'en_BW' => 'îngilîzî (Botswana)',
        'en_BZ' => 'îngilîzî (Belîze)',
        'en_CA' => 'îngilîzî (Kanada)',
        'en_CH' => 'îngilîzî (Swîsre)',
        'en_CK' => 'îngilîzî (Giravên Cook)',
        'en_CM' => 'îngilîzî (Kamerûn)',
        'en_CY' => 'îngilîzî (Kîpros)',
        'en_DE' => 'îngilîzî (Almanya)',
        'en_DK' => 'îngilîzî (Danîmarka)',
        'en_DM' => 'îngilîzî (Domînîka)',
        'en_ER' => 'îngilîzî (Erîtrea)',
        'en_FI' => 'îngilîzî (Fînlenda)',
        'en_FJ' => 'îngilîzî (Fîjî)',
        'en_FK' => 'îngilîzî (Giravên Malvîn)',
        'en_FM' => 'îngilîzî (Mîkronezya)',
        'en_GB' => 'îngilîzî (Keyaniya Yekbûyî)',
        'en_GD' => 'îngilîzî (Grenada)',
        'en_GH' => 'îngilîzî (Gana)',
        'en_GI' => 'îngilîzî (Cîbraltar)',
        'en_GM' => 'îngilîzî (Gambiya)',
        'en_GU' => 'îngilîzî (Guam)',
        'en_GY' => 'îngilîzî (Guyana)',
        'en_HK' => 'îngilîzî (Hong Kong)',
        'en_IE' => 'îngilîzî (Îrlenda)',
        'en_IL' => 'îngilîzî (Îsraêl)',
        'en_IM' => 'îngilîzî (Girava Man)',
        'en_IN' => 'îngilîzî (Hindistan)',
        'en_JM' => 'îngilîzî (Jamaîka)',
        'en_KE' => 'îngilîzî (Kenya)',
        'en_KI' => 'îngilîzî (Kirîbatî)',
        'en_KN' => 'îngilîzî (Saint Kitts û Nevîs)',
        'en_KY' => 'îngilîzî (Giravên Kaymanê)',
        'en_LC' => 'îngilîzî (Saint Lucia)',
        'en_LR' => 'îngilîzî (Lîberya)',
        'en_LS' => 'îngilîzî (Lesoto)',
        'en_MG' => 'îngilîzî (Madagaskar)',
        'en_MH' => 'îngilîzî (Giravên Marşal)',
        'en_MO' => 'îngilîzî (Makao)',
        'en_MP' => 'îngilîzî (Giravên Bakurê Marianan)',
        'en_MT' => 'îngilîzî (Malta)',
        'en_MU' => 'îngilîzî (Maurîtius)',
        'en_MV' => 'îngilîzî (Maldîv)',
        'en_MW' => 'îngilîzî (Malawî)',
        'en_MY' => 'îngilîzî (Malezya)',
        'en_NA' => 'îngilîzî (Namîbya)',
        'en_NF' => 'îngilîzî (Girava Norfolk)',
        'en_NG' => 'îngilîzî (Nîjerya)',
        'en_NL' => 'îngilîzî (Holenda)',
        'en_NR' => 'îngilîzî (Naûrû)',
        'en_NU' => 'îngilîzî (Niûe)',
        'en_NZ' => 'îngilîzî (Nû Zelenda)',
        'en_PG' => 'îngilîzî (Papua Gîneya Nû)',
        'en_PH' => 'îngilîzî (Filîpîn)',
        'en_PK' => 'îngilîzî (Pakistan)',
        'en_PN' => 'îngilîzî (Giravên Pitcairn)',
        'en_PR' => 'îngilîzî (Porto Rîko)',
        'en_PW' => 'îngilîzî (Palau)',
        'en_RW' => 'îngilîzî (Rwanda)',
        'en_SB' => 'îngilîzî (Giravên Salomon)',
        'en_SC' => 'îngilîzî (Seyşel)',
        'en_SD' => 'îngilîzî (Sûdan)',
        'en_SE' => 'îngilîzî (Swêd)',
        'en_SG' => 'îngilîzî (Singapûr)',
        'en_SI' => 'îngilîzî (Slovenya)',
        'en_SL' => 'îngilîzî (Sierra Leone)',
        'en_SS' => 'îngilîzî (Sûdana Başûr)',
        'en_SZ' => 'îngilîzî (Swazîlenda)',
        'en_TC' => 'îngilîzî (Giravên Turk û Kaîkos)',
        'en_TK' => 'îngilîzî (Tokelau)',
        'en_TO' => 'îngilîzî (Tonga)',
        'en_TT' => 'îngilîzî (Trînîdad û Tobago)',
        'en_TV' => 'îngilîzî (Tûvalû)',
        'en_TZ' => 'îngilîzî (Tanzanya)',
        'en_UG' => 'îngilîzî (Ûganda)',
        'en_US' => 'îngilîzî (Dewletên Yekbûyî yên Amerîkayê)',
        'en_VC' => 'îngilîzî (Saint Vincent û Giravên Grenadîn)',
        'en_VU' => 'îngilîzî (Vanûatû)',
        'en_WS' => 'îngilîzî (Samoa)',
        'en_ZA' => 'îngilîzî (Afrîkaya Başûr)',
        'en_ZM' => 'îngilîzî (Zambiya)',
        'en_ZW' => 'îngilîzî (Zîmbabwe)',
        'eo' => 'esperantoyî',
        'eo_001' => 'esperantoyî (Cîhan)',
        'es' => 'spanî',
        'es_419' => 'spanî (Amerîkaya Latînî)',
        'es_AR' => 'spanî (Arjentîn)',
        'es_BO' => 'spanî (Bolîvya)',
        'es_BR' => 'spanî (Brazîl)',
        'es_BZ' => 'spanî (Belîze)',
        'es_CL' => 'spanî (Şîle)',
        'es_CO' => 'spanî (Kolombiya)',
        'es_CR' => 'spanî (Kosta Rîka)',
        'es_CU' => 'spanî (Kûba)',
        'es_DO' => 'spanî (Komara Domînîk)',
        'es_EC' => 'spanî (Ekuador)',
        'es_ES' => 'spanî (Spanya)',
        'es_GQ' => 'spanî (Gîneya Rojbendî)',
        'es_GT' => 'spanî (Guatemala)',
        'es_HN' => 'spanî (Hondûras)',
        'es_MX' => 'spanî (Meksîk)',
        'es_NI' => 'spanî (Nîkaragua)',
        'es_PA' => 'spanî (Panama)',
        'es_PE' => 'spanî (Perû)',
        'es_PH' => 'spanî (Filîpîn)',
        'es_PR' => 'spanî (Porto Rîko)',
        'es_PY' => 'spanî (Paraguay)',
        'es_SV' => 'spanî (El Salvador)',
        'es_US' => 'spanî (Dewletên Yekbûyî yên Amerîkayê)',
        'es_UY' => 'spanî (Ûrûguay)',
        'es_VE' => 'spanî (Venezuela)',
        'et' => 'estonî',
        'et_EE' => 'estonî (Estonya)',
        'eu' => 'baskî',
        'eu_ES' => 'baskî (Spanya)',
        'fa' => 'farisî',
        'fa_AF' => 'farisî (Efxanistan)',
        'fa_IR' => 'farisî (Îran)',
        'ff' => 'fulahî',
        'ff_CM' => 'fulahî (Kamerûn)',
        'ff_GN' => 'fulahî (Gîne)',
        'ff_Latn' => 'fulahî (latînî)',
        'ff_Latn_BF' => 'fulahî (latînî, Burkîna Faso)',
        'ff_Latn_CM' => 'fulahî (latînî, Kamerûn)',
        'ff_Latn_GH' => 'fulahî (latînî, Gana)',
        'ff_Latn_GM' => 'fulahî (latînî, Gambiya)',
        'ff_Latn_GN' => 'fulahî (latînî, Gîne)',
        'ff_Latn_GW' => 'fulahî (latînî, Gîne-Bissau)',
        'ff_Latn_LR' => 'fulahî (latînî, Lîberya)',
        'ff_Latn_MR' => 'fulahî (latînî, Morîtanya)',
        'ff_Latn_NE' => 'fulahî (latînî, Nîjer)',
        'ff_Latn_NG' => 'fulahî (latînî, Nîjerya)',
        'ff_Latn_SL' => 'fulahî (latînî, Sierra Leone)',
        'ff_Latn_SN' => 'fulahî (latînî, Senegal)',
        'ff_MR' => 'fulahî (Morîtanya)',
        'ff_SN' => 'fulahî (Senegal)',
        'fi' => 'fînî',
        'fi_FI' => 'fînî (Fînlenda)',
        'fo' => 'ferî',
        'fo_DK' => 'ferî (Danîmarka)',
        'fo_FO' => 'ferî (Giravên Feroe)',
        'fr' => 'frensî',
        'fr_BE' => 'frensî (Belçîka)',
        'fr_BF' => 'frensî (Burkîna Faso)',
        'fr_BI' => 'frensî (Burundî)',
        'fr_BJ' => 'frensî (Bênîn)',
        'fr_BL' => 'frensî (Saint-Barthélemy)',
        'fr_CA' => 'frensî (Kanada)',
        'fr_CD' => 'frensî (Kongo - Kînşasa)',
        'fr_CF' => 'frensî (Komara Afrîkaya Navend)',
        'fr_CG' => 'frensî (Kongo - Brazzaville)',
        'fr_CH' => 'frensî (Swîsre)',
        'fr_CI' => 'frensî (Peravê Diranfîl)',
        'fr_CM' => 'frensî (Kamerûn)',
        'fr_DJ' => 'frensî (Cîbûtî)',
        'fr_DZ' => 'frensî (Cezayir)',
        'fr_FR' => 'frensî (Fransa)',
        'fr_GA' => 'frensî (Gabon)',
        'fr_GF' => 'frensî (Guyanaya Fransî)',
        'fr_GN' => 'frensî (Gîne)',
        'fr_GP' => 'frensî (Guadeloupe)',
        'fr_GQ' => 'frensî (Gîneya Rojbendî)',
        'fr_HT' => 'frensî (Haîtî)',
        'fr_KM' => 'frensî (Komor)',
        'fr_LU' => 'frensî (Lûksembûrg)',
        'fr_MA' => 'frensî (Maroko)',
        'fr_MC' => 'frensî (Monako)',
        'fr_MG' => 'frensî (Madagaskar)',
        'fr_ML' => 'frensî (Malî)',
        'fr_MQ' => 'frensî (Martinique)',
        'fr_MR' => 'frensî (Morîtanya)',
        'fr_MU' => 'frensî (Maurîtius)',
        'fr_NC' => 'frensî (Kaledonyaya Nû)',
        'fr_NE' => 'frensî (Nîjer)',
        'fr_PF' => 'frensî (Polînezyaya Fransî)',
        'fr_PM' => 'frensî (Saint-Pierre û Miquelon)',
        'fr_RE' => 'frensî (Réunion)',
        'fr_RW' => 'frensî (Rwanda)',
        'fr_SC' => 'frensî (Seyşel)',
        'fr_SN' => 'frensî (Senegal)',
        'fr_SY' => 'frensî (Sûrî)',
        'fr_TD' => 'frensî (Çad)',
        'fr_TG' => 'frensî (Togo)',
        'fr_TN' => 'frensî (Tûnis)',
        'fr_VU' => 'frensî (Vanûatû)',
        'fr_WF' => 'frensî (Wallis û Futuna)',
        'fy' => 'frîsî',
        'fy_NL' => 'frîsî (Holenda)',
        'ga' => 'îrî',
        'ga_GB' => 'îrî (Keyaniya Yekbûyî)',
        'ga_IE' => 'îrî (Îrlenda)',
        'gd' => 'gaelîka skotî',
        'gd_GB' => 'gaelîka skotî (Keyaniya Yekbûyî)',
        'gl' => 'galîsî',
        'gl_ES' => 'galîsî (Spanya)',
        'gu' => 'gujaratî',
        'gu_IN' => 'gujaratî (Hindistan)',
        'gv' => 'manksî',
        'gv_IM' => 'manksî (Girava Man)',
        'ha' => 'hawsayî',
        'ha_GH' => 'hawsayî (Gana)',
        'ha_NE' => 'hawsayî (Nîjer)',
        'ha_NG' => 'hawsayî (Nîjerya)',
        'he' => 'îbranî',
        'he_IL' => 'îbranî (Îsraêl)',
        'hi' => 'hindî',
        'hi_IN' => 'hindî (Hindistan)',
        'hi_Latn' => 'hindî (latînî)',
        'hi_Latn_IN' => 'hindî (latînî, Hindistan)',
        'hr' => 'xirwatî',
        'hr_BA' => 'xirwatî (Bosniya û Herzegovîna)',
        'hr_HR' => 'xirwatî (Kroatya)',
        'hu' => 'mecarî',
        'hu_HU' => 'mecarî (Macaristan)',
        'hy' => 'ermenî',
        'hy_AM' => 'ermenî (Ermenistan)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (Cîhan)',
        'id' => 'indonezî',
        'id_ID' => 'indonezî (Îndonezya)',
        'ig' => 'îgboyî',
        'ig_NG' => 'îgboyî (Nîjerya)',
        'is' => 'îzlendî',
        'is_IS' => 'îzlendî (Îslenda)',
        'it' => 'îtalî',
        'it_CH' => 'îtalî (Swîsre)',
        'it_IT' => 'îtalî (Îtalya)',
        'it_SM' => 'îtalî (San Marîno)',
        'it_VA' => 'îtalî (Vatîkan)',
        'ja' => 'japonî',
        'ja_JP' => 'japonî (Japon)',
        'jv' => 'javayî',
        'jv_ID' => 'javayî (Îndonezya)',
        'ka' => 'gurcî',
        'ka_GE' => 'gurcî (Gurcistan)',
        'kk' => 'qazaxî',
        'kk_KZ' => 'qazaxî (Qazaxistan)',
        'kl' => 'kalalîsûtî',
        'kl_GL' => 'kalalîsûtî (Grînlenda)',
        'km' => 'ximêrî',
        'km_KH' => 'ximêrî (Kamboca)',
        'kn' => 'kannadayî',
        'kn_IN' => 'kannadayî (Hindistan)',
        'ko' => 'koreyî',
        'ko_KP' => 'koreyî (Korêya Bakur)',
        'ko_KR' => 'koreyî (Korêya Başûr)',
        'ks' => 'keşmîrî',
        'ks_Arab' => 'keşmîrî (erebî)',
        'ks_Arab_IN' => 'keşmîrî (erebî, Hindistan)',
        'ks_Deva' => 'keşmîrî (devanagarî)',
        'ks_Deva_IN' => 'keşmîrî (devanagarî, Hindistan)',
        'ks_IN' => 'keşmîrî (Hindistan)',
        'ku' => 'kurdî',
        'ku_TR' => 'kurdî (Tirkiye)',
        'kw' => 'kornî',
        'kw_GB' => 'kornî (Keyaniya Yekbûyî)',
        'ky' => 'kirgizî',
        'ky_KG' => 'kirgizî (Qirgizistan)',
        'lb' => 'luksembûrgî',
        'lb_LU' => 'luksembûrgî (Lûksembûrg)',
        'lg' => 'lugandayî',
        'lg_UG' => 'lugandayî (Ûganda)',
        'ln' => 'lingalayî',
        'ln_AO' => 'lingalayî (Angola)',
        'ln_CD' => 'lingalayî (Kongo - Kînşasa)',
        'ln_CF' => 'lingalayî (Komara Afrîkaya Navend)',
        'ln_CG' => 'lingalayî (Kongo - Brazzaville)',
        'lo' => 'lawsî',
        'lo_LA' => 'lawsî (Laos)',
        'lt' => 'lîtwanî',
        'lt_LT' => 'lîtwanî (Lîtvanya)',
        'lv' => 'latviyayî',
        'lv_LV' => 'latviyayî (Letonya)',
        'mg' => 'malagasî',
        'mg_MG' => 'malagasî (Madagaskar)',
        'mi' => 'maorî',
        'mi_NZ' => 'maorî (Nû Zelenda)',
        'mk' => 'makedonî',
        'mk_MK' => 'makedonî (Makedonya)',
        'ml' => 'malayalamî',
        'ml_IN' => 'malayalamî (Hindistan)',
        'mn' => 'mongolî',
        'mn_MN' => 'mongolî (Mongolya)',
        'mr' => 'maratî',
        'mr_IN' => 'maratî (Hindistan)',
        'ms' => 'malezî',
        'ms_BN' => 'malezî (Brûney)',
        'ms_ID' => 'malezî (Îndonezya)',
        'ms_MY' => 'malezî (Malezya)',
        'ms_SG' => 'malezî (Singapûr)',
        'mt' => 'maltayî',
        'mt_MT' => 'maltayî (Malta)',
        'my' => 'burmayî',
        'my_MM' => 'burmayî (Myanmar [Birmanya])',
        'nb' => 'norwecî [bokmål]',
        'nb_NO' => 'norwecî [bokmål] (Norwêc)',
        'ne' => 'nepalî',
        'ne_IN' => 'nepalî (Hindistan)',
        'ne_NP' => 'nepalî (Nepal)',
        'nl' => 'holendî',
        'nl_AW' => 'holendî (Arûba)',
        'nl_BE' => 'holendî (Belçîka)',
        'nl_NL' => 'holendî (Holenda)',
        'nl_SR' => 'holendî (Sûrînam)',
        'nn' => 'norwecî [nynorsk]',
        'nn_NO' => 'norwecî [nynorsk] (Norwêc)',
        'om' => 'oromoyî',
        'om_ET' => 'oromoyî (Etiyopya)',
        'om_KE' => 'oromoyî (Kenya)',
        'or' => 'oriyayî',
        'or_IN' => 'oriyayî (Hindistan)',
        'os' => 'osetî',
        'os_GE' => 'osetî (Gurcistan)',
        'os_RU' => 'osetî (Rûsya)',
        'pa' => 'puncabî',
        'pa_Arab' => 'puncabî (erebî)',
        'pa_Arab_PK' => 'puncabî (erebî, Pakistan)',
        'pa_IN' => 'puncabî (Hindistan)',
        'pa_PK' => 'puncabî (Pakistan)',
        'pl' => 'polonî',
        'pl_PL' => 'polonî (Polonya)',
        'ps' => 'peştûyî',
        'ps_AF' => 'peştûyî (Efxanistan)',
        'ps_PK' => 'peştûyî (Pakistan)',
        'pt' => 'portugalî',
        'pt_AO' => 'portugalî (Angola)',
        'pt_BR' => 'portugalî (Brazîl)',
        'pt_CH' => 'portugalî (Swîsre)',
        'pt_CV' => 'portugalî (Kap Verde)',
        'pt_GQ' => 'portugalî (Gîneya Rojbendî)',
        'pt_GW' => 'portugalî (Gîne-Bissau)',
        'pt_LU' => 'portugalî (Lûksembûrg)',
        'pt_MO' => 'portugalî (Makao)',
        'pt_MZ' => 'portugalî (Mozambîk)',
        'pt_PT' => 'portugalî (Portûgal)',
        'pt_ST' => 'portugalî (Sao Tome û Prînsîpe)',
        'pt_TL' => 'portugalî (Tîmora-Leste)',
        'qu' => 'keçwayî',
        'qu_BO' => 'keçwayî (Bolîvya)',
        'qu_EC' => 'keçwayî (Ekuador)',
        'qu_PE' => 'keçwayî (Perû)',
        'rm' => 'romancî',
        'rm_CH' => 'romancî (Swîsre)',
        'ro' => 'romanî',
        'ro_MD' => 'romanî (Moldova)',
        'ro_RO' => 'romanî (Romanya)',
        'ru' => 'rusî',
        'ru_BY' => 'rusî (Belarûs)',
        'ru_KG' => 'rusî (Qirgizistan)',
        'ru_KZ' => 'rusî (Qazaxistan)',
        'ru_MD' => 'rusî (Moldova)',
        'ru_RU' => 'rusî (Rûsya)',
        'ru_UA' => 'rusî (Ûkrayna)',
        'rw' => 'kînyariwandayî',
        'rw_RW' => 'kînyariwandayî (Rwanda)',
        'sa' => 'sanskrîtî',
        'sa_IN' => 'sanskrîtî (Hindistan)',
        'sc' => 'sardînî',
        'sc_IT' => 'sardînî (Îtalya)',
        'sd' => 'sindhî',
        'sd_Arab' => 'sindhî (erebî)',
        'sd_Arab_PK' => 'sindhî (erebî, Pakistan)',
        'sd_Deva' => 'sindhî (devanagarî)',
        'sd_Deva_IN' => 'sindhî (devanagarî, Hindistan)',
        'sd_IN' => 'sindhî (Hindistan)',
        'sd_PK' => 'sindhî (Pakistan)',
        'se' => 'samiya bakur',
        'se_FI' => 'samiya bakur (Fînlenda)',
        'se_NO' => 'samiya bakur (Norwêc)',
        'se_SE' => 'samiya bakur (Swêd)',
        'si' => 'kîngalî',
        'si_LK' => 'kîngalî (Srî Lanka)',
        'sk' => 'slovakî',
        'sk_SK' => 'slovakî (Slovakya)',
        'sl' => 'slovenî',
        'sl_SI' => 'slovenî (Slovenya)',
        'sn' => 'şonayî',
        'sn_ZW' => 'şonayî (Zîmbabwe)',
        'so' => 'somalî',
        'so_DJ' => 'somalî (Cîbûtî)',
        'so_ET' => 'somalî (Etiyopya)',
        'so_KE' => 'somalî (Kenya)',
        'so_SO' => 'somalî (Somalya)',
        'sq' => 'elbanî',
        'sq_AL' => 'elbanî (Albanya)',
        'sq_MK' => 'elbanî (Makedonya)',
        'sr' => 'sirbî',
        'sr_BA' => 'sirbî (Bosniya û Herzegovîna)',
        'sr_Cyrl' => 'sirbî (kirîlî)',
        'sr_Cyrl_BA' => 'sirbî (kirîlî, Bosniya û Herzegovîna)',
        'sr_Cyrl_ME' => 'sirbî (kirîlî, Montenegro)',
        'sr_Cyrl_RS' => 'sirbî (kirîlî, Serbistan)',
        'sr_Latn' => 'sirbî (latînî)',
        'sr_Latn_BA' => 'sirbî (latînî, Bosniya û Herzegovîna)',
        'sr_Latn_ME' => 'sirbî (latînî, Montenegro)',
        'sr_Latn_RS' => 'sirbî (latînî, Serbistan)',
        'sr_ME' => 'sirbî (Montenegro)',
        'sr_RS' => 'sirbî (Serbistan)',
        'su' => 'sundanî',
        'su_ID' => 'sundanî (Îndonezya)',
        'su_Latn' => 'sundanî (latînî)',
        'su_Latn_ID' => 'sundanî (latînî, Îndonezya)',
        'sv' => 'swêdî',
        'sv_FI' => 'swêdî (Fînlenda)',
        'sv_SE' => 'swêdî (Swêd)',
        'sw' => 'swahîlî',
        'sw_CD' => 'swahîlî (Kongo - Kînşasa)',
        'sw_KE' => 'swahîlî (Kenya)',
        'sw_TZ' => 'swahîlî (Tanzanya)',
        'sw_UG' => 'swahîlî (Ûganda)',
        'ta' => 'tamîlî',
        'ta_IN' => 'tamîlî (Hindistan)',
        'ta_LK' => 'tamîlî (Srî Lanka)',
        'ta_MY' => 'tamîlî (Malezya)',
        'ta_SG' => 'tamîlî (Singapûr)',
        'te' => 'telûgûyî',
        'te_IN' => 'telûgûyî (Hindistan)',
        'tg' => 'tacikî',
        'tg_TJ' => 'tacikî (Tacîkistan)',
        'th' => 'tayî',
        'th_TH' => 'tayî (Taylenda)',
        'ti' => 'tigrînî',
        'ti_ER' => 'tigrînî (Erîtrea)',
        'ti_ET' => 'tigrînî (Etiyopya)',
        'tk' => 'tirkmenî',
        'tk_TM' => 'tirkmenî (Tirkmenistan)',
        'to' => 'tongî',
        'to_TO' => 'tongî (Tonga)',
        'tr' => 'tirkî',
        'tr_CY' => 'tirkî (Kîpros)',
        'tr_TR' => 'tirkî (Tirkiye)',
        'tt' => 'teterî',
        'tt_RU' => 'teterî (Rûsya)',
        'ug' => 'oygurî',
        'ug_CN' => 'oygurî (Çîn)',
        'uk' => 'ukraynî',
        'uk_UA' => 'ukraynî (Ûkrayna)',
        'ur' => 'urdûyî',
        'ur_IN' => 'urdûyî (Hindistan)',
        'ur_PK' => 'urdûyî (Pakistan)',
        'uz' => 'ozbekî',
        'uz_AF' => 'ozbekî (Efxanistan)',
        'uz_Arab' => 'ozbekî (erebî)',
        'uz_Arab_AF' => 'ozbekî (erebî, Efxanistan)',
        'uz_Cyrl' => 'ozbekî (kirîlî)',
        'uz_Cyrl_UZ' => 'ozbekî (kirîlî, Ûzbêkistan)',
        'uz_Latn' => 'ozbekî (latînî)',
        'uz_Latn_UZ' => 'ozbekî (latînî, Ûzbêkistan)',
        'uz_UZ' => 'ozbekî (Ûzbêkistan)',
        'vi' => 'viyetnamî',
        'vi_VN' => 'viyetnamî (Viyetnam)',
        'wo' => 'wolofî',
        'wo_SN' => 'wolofî (Senegal)',
        'xh' => 'xosayî',
        'xh_ZA' => 'xosayî (Afrîkaya Başûr)',
        'yi' => 'yidîşî',
        'yi_001' => 'yidîşî (Cîhan)',
        'yo' => 'yorubayî',
        'yo_BJ' => 'yorubayî (Bênîn)',
        'yo_NG' => 'yorubayî (Nîjerya)',
        'zu' => 'zuluyî',
        'zu_ZA' => 'zuluyî (Afrîkaya Başûr)',
    ],
];
